% Software for the evaluation of laser-induced stripes in cell nuclei.
% Positive Stripes
% 
% The method is described here:
% Martin Mistrik, Eva Vesela, et al:
% Cells and Stripes: A novel quantitative photo-manipulation technique
% Scientific Reports, to appear.

% First, run the 'Segment_and_Track.m' routine.
% This routine will read the 'segmentdata.mat' file and all the images in the 'Data' folder.
% Be careful, if you change the content of the 'Data' folder in the meantime, 'Evaluate_Stripes.mat' will probably crash
% because it expects that the 'segmentdata.mat' file contains info about the images in the 'Data' folder.
% The routine will evaluate the measure of striation (see the article) of the individual nuclei at all time points
% and produce several '*.csv' files and two figures which will be written into the 'Results' folder.

%% READ SEGMENTDATA

load segmentdata % the structure 'celkvysl' resulting from tracking
% celkvysl(i):
%     name (filename: char)
%     data ([area, xcenter, ycenter, solidity, rows, columns] individual objects)
%     mask (logical mask with objects, may be merged, only for preview)

S = dir('Data\*.tif*');
names = {S.name};


%% READ ALL IMAGES INTO SINGLE STRUCTURE
% raw data, no filters

n = length(celkvysl);
[mm nn] = size(celkvysl(1).mask);
OBR = uint16(zeros(mm,nn,n)); % allocation

for i=1:1:n

    jm = ['Data\' char(celkvysl(i).name)];
    pom = imread(jm,'tif');
    disp(['Reading file ' char(celkvysl(i).name)])
    OBR(:,:,i) = pom(:,:);
    
end


%% COMPUTE CHARS

bunek = length(celkvysl(1).data); % no. objects
RES = zeros(bunek,n,5); % allocation for characteristics 
% [SID_object Area_object SID_stripes Area_stripes MS]
ROT = 90*ones(bunek,n); % allocation for the correct rotation
% b=objects, n=times

for b=1:1:bunek % over all objects
    
    for cas = 1:1:n % over all times
        
        disp(['time = ' num2str(cas) ', object = ' num2str(b)])
                
        pom = celkvysl(cas).data;
        treatstat = pom(b); % chars of object 'b' at time 'cas'
        if treatstat.area==0 % nothing there
            RES(b,cas,:) = NaN; % nothing here either
        else
            rad =  pom(b).rad;
            sloup = pom(b).sloup;
            odr = min(rad);
            dor = max(rad);
            ods = min(sloup);
            dos = max(sloup);
            treat = OBR(odr:dor,ods:dos,cas); % clip of the cell
            mask = false(mm,nn); % allocation for the mask
            ind = sub2ind(size(mask),rad,sloup);
            mask(ind) = true;
            treatmask = mask(odr:dor,ods:dos);
            treat(~treatmask)=0; % object without background

            if cas<=2 % first two times, no idea about rotation
               orot = 90; % probably horizontally
            else
                orot = ROT(b,cas-1); % previous rotation
            end 

            [radonek uhel] = prouzky_dna4(treat,treatmask,pars,orot); 
            % radonek = [SID_object Area_object SID_stripes Area_stripes MS]
            RES(b,cas,:) = radonek;
            ROT(b,cas:end) = uhel;
            
        end % if nothing there
        
    end % over time
    
end % over cells

%% WRIRE CSV RESULTS

mkdir('Results')
%   nucleus Signal Integrated Density (SID), i.e. the sum of gray-scale
%   levels of pixels belonging to the particular nucleus at the particular time
dataout = RES(:,:,1); 
jmout = 'Results\NucleusSID.csv';
csvwrite(jmout,dataout);

% 	nucleus area, i.e. the number of pixels belonging to the particular nucleus at the particular time
dataout = RES(:,:,2);
jmout = 'Results\NucleusArea.csv';
csvwrite(jmout,dataout);

% 	stripe SID, i.e. the sum of the gray-scale levels of pixels in the part
% 	of the nucleus which is identified as a stripe
dataout = RES(:,:,3); 
jmout = 'Results\StripeSID.csv';
csvwrite(jmout,dataout);

% 	stripe area, i.e. the number of pixels in the part of the nucleus which
% 	is identified as a stripe
dataout = RES(:,:,4); 
jmout = 'Results\StripeArea.csv';
csvwrite(jmout,dataout);

% 	measure of striation, i.e. the measure of striation (MS) of the particular nucleus at the particular time 
%  (see the article for the definiton of MS)
dataout = RES(:,:,5); 
jmout = 'Results\MeasureOfStriation.csv';
csvwrite(jmout,dataout);


%% WRITE FIGURES

h = figure;
boxplot(dataout)
xlabel('Index of time point')
ylabel('Measure of striation')
title('Evolution of the measure of striation')
jmout = 'Results\MeasureOfStriationBoxplot.png';
saveas(h,jmout,'png');

h = figure;
plot(dataout')
xlabel('Index of time point')
ylabel('Measure of striation')
title('Tracking of the measure of striation')
jmout = 'Results\MeasureOfStriationLineplot.png';
saveas(h,jmout,'png');

        
%%

disp('Results written into the Results folder.')
disp('See _readme.txt to understand the results format.')

    

